Welcome to Deprecation Factory's documentation!
===============================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   README
   installation
   usage
   modules

   examples

   HISTORY

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
